#!/usr/bin/perl

# The ATMEL chipset is a popular bridge in man wireless access points
# my netgear, smc, and linksys. I'm working with linksys wap11's here.
# This script uses cricket's snmpUtil's library to fetch statistics
# from the wap devices. Stats from the devices come in strings of 
# packed unsigned longs. This script merely fetches, unpacks, and prints

# note: perl's unpack assumes 32bit longs. Native on x86 is 64. See pack for details.

# Jim Weller
# jim@jimweller.net
# http://jimweller.net
# 8/3/2003 10:36PM

BEGIN {
	$gInstallRoot = (($0 =~ m:^(.*/):)[0] || "./") . "..";
}

use lib "$gInstallRoot/lib";
use strict;
use snmpUtils;


if ( scalar @ARGV != 2 ) {
	print "Usage: $0 host community\n";
	exit 2;
}

my $host = $ARGV[0];
my $community = $ARGV[1];
my $snmp_string = "$community\@$host";

my ($wlanStatsPack) = snmpUtils::get($snmp_string,".1.3.6.1.4.1.410.1.2.3.1.0");
my (
	$UnicastTransmittedPackets,
	$BroadcastTransmittedpackets,
	$MulticastTransmittedPackets,
	$TransmittedBeacon,
	$TransmittedACK,
	$TransmittedRTS,
	$TransmittedCTS,
	$UnicastReceivedPackets,
	$BroadcastReceivedPackets,
	$MulticastReceivedPackets,
	$ReceivedBeacon,
	$ReceivedACK,
	$ReceivedRTS,
	$ReceivedCTS,
	$ACKFailure,
	$CTSFailure,
	$RetryPackets,
	$ReceivedDuplicate,
	$FailedPackets,
	$AgedPackets,
	$FCSError,
	$InvalidPLCP
	) = unpack("L!22",$wlanStatsPack);

my ($ethRxPack) = snmpUtils::get($snmp_string,".1.3.6.1.4.1.410.1.1.7.1.0");
my (
	$TotalBytesRx,
	$TotalPacketsRx,
	$PacketCRCErrorRx,
	$MulticastPacketRx,
	$BroadcastPacketRx,
	$ControlFramesRx,
	$PauseFramesRx,
	$UnknownOPCodeRx,
	$AlignmentRxError,
	$LengthOutOfRangeRx,
	$CodeErrorRx,
	$FalseCarrierRx,
	$UndersizePacketsRx,
	$OversizePacketsRx,
	$TotalFragmentsRx,
	$TotalJabberRx
	) = unpack("L!14",$ethRxPack);

my ($ethTxPack) = snmpUtils::get($snmp_string,".1.3.6.1.4.1.410.1.1.7.2.0");
my (
	$TotalBytesTx,
	$TotalPacketsTx,
	$PacketCRCErrorTx,
	$MulticastPacketTx,
	$BroadcastPacketTx,
	$UnicastPacketTx,
	$PauseFramesTx,
	$SingleDeferPacketTx,
	$MultiDeferPacketsTx,
	$SingleCollisionsTx,
	$MultiCollisionsTx,
	$LateCollisionsTx,
	$ExcessiveCollisionTx,
	$TotalCollisionsTx
	) = unpack("L!14",$ethTxPack);



print <<END
$UnicastTransmittedPackets
$BroadcastTransmittedpackets
$MulticastTransmittedPackets
$TransmittedBeacon
$TransmittedACK
$TransmittedRTS
$TransmittedCTS
$UnicastReceivedPackets
$BroadcastReceivedPackets
$MulticastReceivedPackets
$ReceivedBeacon
$ReceivedACK
$ReceivedRTS
$ReceivedCTS
$ACKFailure
$CTSFailure
$RetryPackets
$ReceivedDuplicate
$FailedPackets
$AgedPackets
$FCSError
$InvalidPLCP
$TotalBytesRx
$TotalPacketsRx
$PacketCRCErrorRx
$MulticastPacketRx
$BroadcastPacketRx
$ControlFramesRx
$PauseFramesRx
$UnknownOPCodeRx
$AlignmentRxError
$LengthOutOfRangeRx
$CodeErrorRx
$FalseCarrierRx
$UndersizePacketsRx
$OversizePacketsRx
$TotalFragmentsRx
$TotalJabberRx
$TotalBytesTx
$TotalPacketsTx
$PacketCRCErrorTx
$MulticastPacketTx
$BroadcastPacketTx
$UnicastPacketTx
$PauseFramesTx
$SingleDeferPacketTx
$MultiDeferPacketsTx
$SingleCollisionsTx
$MultiCollisionsTx
$LateCollisionsTx
$ExcessiveCollisionTx
$TotalCollisionsTx
END

